@@ -13,14 +13,14 @@ EdgeOrientation <- function (gInput,GV,suffStat,FDR,alpha,indepTest,FDRcontrol,v
   
   # extract all edges
   g[lower.tri(g)] <- 0  # Use only upper triangular because g is symmetric matrix
-  edges <- which (g==1, arr.ind=TRUE)
+  edges <- which (g==1, arr.ind = TRUE)
   
   #Step-1 start
   if (GV>0) {
     # identify edges involving Vs
-    edgesWithBothVs <- edges[which (edges[,1]<= GV & edges[,2]<=GV), ]
-    edgesWithVFirst <- edges[which (edges[,1]<= GV & edges[,2]>GV), ]
-    edgesWithVSecond <- edges[which (edges[,1]> GV & edges[,2]<=GV), ]
+    edgesWithBothVs <- edges[which (edges[,1] <= GV & edges[,2] <= GV), ]
+    edgesWithVFirst <- edges[which (edges[,1] <= GV & edges[,2] > GV), ]
+    edgesWithVSecond <- edges[which (edges[,1] > GV & edges[,2] <= GV), ]
     
     # assign 1s to corresponding edges in tarmat
     # edges between two Vs are undirected (or bidirected)
@@ -50,6 +50,7 @@ EdgeOrientation <- function (gInput,GV,suffStat,FDR,alpha,indepTest,FDRcontrol,v
   
   #Step-2 start
   #Start to orient v-structures
+  if (verbose)
   cat("\n V-structures are as follows :\n")
   # extract edges involving at least one gene node
   #edgesWithGs <- edges[which (edges[,1]>GV | edges[,2]>GV), ]
@@ -74,7 +75,7 @@ EdgeOrientation <- function (gInput,GV,suffStat,FDR,alpha,indepTest,FDRcontrol,v
         {
           pval <- gaussCItest(x, z, y, suffStat)
         }
-        if(indepTest=="disCItest") #if indepTest=gaussCItest
+        if(indepTest=="disCItest") #if indepTest=disCItest
         {
           pval <- disCItest(x, z, y, suffStat) #additional
         }
@@ -86,10 +87,12 @@ EdgeOrientation <- function (gInput,GV,suffStat,FDR,alpha,indepTest,FDRcontrol,v
         {
           Alpha <- alpha
         }
-        cat("x=", x, " y=", y, " S=", z,"\n")
+        if (verbose){
+        cat("x=", x, " y=", z, " S=", y,"\n")
         cat("Test number =", m, "\n")
         cat("Additional pval value =", pval, "\n")
         cat("Alpha value =", Alpha, "\n")
+        }
         if (pval<= Alpha) {  #Reject H0 (H0:nodes are independent)
           R[m] <- 1
           if (verbose) {
@@ -100,6 +103,8 @@ EdgeOrientation <- function (gInput,GV,suffStat,FDR,alpha,indepTest,FDRcontrol,v
         } 
         else {
           R[m] <- 0  #Accept H0
+          #tarmat[x, y] <- tarmat[y, z] <- 1 #directed x-->y-->z
+          if (verbose)
           cat("Since pval>Alpha,additional test is accepted;", "Nodes", V[x] ,"and" ,V[z] ,"are independent given", V[y], "\n")
         }
         
@@ -162,7 +167,7 @@ EdgeOrientation <- function (gInput,GV,suffStat,FDR,alpha,indepTest,FDRcontrol,v
                 m <- m+1
                 if(indepTest=="gaussCItest") #if indepTest=gaussCItest for continuous data
                 {
-                  pval<- gaussCItest(x, z, y, suffStat) #additional pval
+                  pval <- gaussCItest(x, z, y, suffStat) #additional pval
                 }
                 if(indepTest=="disCItest") #if indepTest=disCItest for discrete data 
                 {
@@ -177,9 +182,12 @@ EdgeOrientation <- function (gInput,GV,suffStat,FDR,alpha,indepTest,FDRcontrol,v
                 {
                   Alpha <- alpha
                 }
-                cat("Additional pval value =", pval, "\n")
-                cat("Alpha value =", Alpha, "\n")
-                if (pval<= Alpha) {  #Reject H0 (H0:nodes are independent)
+                if (verbose){
+                  cat("Additional pval value =", pval, "\n")
+                  cat("Alpha value =", Alpha, "\n")    
+                }
+
+                if (pval <= Alpha) {  #Reject H0 (H0:nodes are independent)
                   R[m] <- 1
                   if (verbose) {
                     V <- colnames(g)
@@ -262,7 +270,7 @@ EdgeOrientation <- function (gInput,GV,suffStat,FDR,alpha,indepTest,FDRcontrol,v
                 {
                   Alpha <- alpha
                 }
-                if (pval<= Alpha) {  #Reject H0 (H0:nodes are independent)
+                if (pval <= Alpha) {  #Reject H0 (H0:nodes are independent)
                   R[m] <- 1
                   
                   if (verbose) {
@@ -314,7 +322,7 @@ EdgeOrientation <- function (gInput,GV,suffStat,FDR,alpha,indepTest,FDRcontrol,v
   #Start when data not necessary to contain genetic variants.
   if (any(tarmat == 1) & GV==0) #if at least one edge directed already made so far
   {
-    WW1 <- unique(which(tarmat==1,arr.ind = T)[,2]) #pullout the all canidate genes for v-structure
+    WW1 <- unique(which(tarmat == 1,arr.ind = T)[,2]) #pullout the all canidate genes for v-structure
     #WW1=WW1[-c(1:GV)]
     if(length(WW1)!=0)
     {
@@ -363,9 +371,10 @@ EdgeOrientation <- function (gInput,GV,suffStat,FDR,alpha,indepTest,FDRcontrol,v
                 {
                   Alpha <- alpha
                 }
+                if (verbose) {
                 cat("Additional pval value =", pval, "\n")
                 cat("Alpha value =", Alpha, "\n")
-                
+                }
                 #Alpha=SeqFDR(m,FDR,a=2,R) #Alpha valued from sequential FDR test
                 if (pval<= Alpha) {  #Reject H0 (H0:nodes are independent)
                   R[m] <- 1
